@@ -5,7 +5,6 @@
 
 from __future__ import with_statement
 
-import copy
 import errno
 import logging
 import os
@@ -17,7 +16,6 @@ import traceback
 
 from gunicorn.pidfile import Pidfile
 from gunicorn.sock import create_socket
-from gunicorn.workers.sync import SyncWorker
 from gunicorn import util
 
 class Arbiter(object):
@@ -44,27 +42,23 @@ class Arbiter(object):
         if name[:3] == "SIG" and name[3] != "_"
     )
     
-    pidfile = Pidfile()
-
-    def __init__(self, cfg, app):
-        self.cfg = cfg
+    def __init__(self, app):
         self.app = app
+        self.cfg = app.cfg
+        
+        if self.cfg.preload_app:
+            self.app.wsgi()
 
         self.log = logging.getLogger(__name__)
 
-        self.address = cfg.address
-        self.num_workers = cfg.workers
-        self.debug = cfg.debug
-        self.timeout = cfg.timeout
-        self.proc_name = cfg.proc_name
-        
-        try:
-            self.worker_class = cfg.worker_class
-        except ImportError, e:
-            self.log.error("%s" % e)
-            sys.exit(1)
-        
-        self._pidfile = None
+        self.address = self.cfg.address
+        self.num_workers = self.cfg.workers
+        self.debug = self.cfg.debug
+        self.timeout = self.cfg.timeout
+        self.proc_name = self.cfg.proc_name
+        self.worker_class = self.cfg.worker_class
+
+        self.pidfile = None
         self.worker_age = 0
         self.reexec_pid = 0
         self.master_name = "Master"
@@ -80,11 +74,14 @@ class Arbiter(object):
         except:
             cwd = os.getcwd()
             
+        args = sys.argv[:]
+        args.insert(0, sys.executable)
+
         # init start context
         self.START_CTX = {
-            "argv": copy.copy(sys.argv),
+            "args": args,
             "cwd": cwd,
-            0: copy.copy(sys.argv[0])
+            0: sys.executable
         }
 
     def start(self):
@@ -94,10 +91,13 @@ class Arbiter(object):
         self.pid = os.getpid()
         self.init_signals()
         self.LISTENER = create_socket(self.cfg)
-        self.pidfile = self.cfg.pidfile
+        
+        if self.cfg.pidfile is not None:
+            self.pidfile = Pidfile(self.cfg.pidfile)
+            self.pidfile.create(self.pid)
         self.log.info("Arbiter booted")
         self.log.info("Listening at: %s" % self.LISTENER)
-        
+        self.cfg.when_ready(self)
     
     def init_signals(self):
         """\
@@ -154,14 +154,14 @@ class Arbiter(object):
                 self.log.info("Unhandled exception in main loop:\n%s" %  
                             traceback.format_exc())
                 self.stop(False)
-                if self.pidfile:
-                    del self.pidfile
+                if self.pidfile is not None:
+                    self.pidfile.unlink()
                 sys.exit(-1)
 
         self.stop()
         self.log.info("Shutting down: %s" % self.master_name)
-        if self.pidfile:
-            del self.pidfile
+        if self.pidfile is not None:
+            self.pidfile.unlink()
         sys.exit(0)
         
     def handle_chld(self, sig, frame):
@@ -287,9 +287,8 @@ class Arbiter(object):
         """\
         Relaunch the master and workers.
         """
-        if self.pidfile:
-            old_pidfile = "%s.oldbin" % self.pidfile
-            self.pidfile = old_pidfile            
+        if self.pidfile is not None:
+            self.pidfile.rename("%s.oldbin" % self.pidfile.fname)
         
         self.reexec_pid = os.fork()
         if self.reexec_pid != 0:
@@ -298,8 +297,8 @@ class Arbiter(object):
             
         os.environ['GUNICORN_FD'] = str(self.LISTENER.fileno())
         os.chdir(self.START_CTX['cwd'])
-        self.cfg.before_exec(self)
-        os.execlp(self.START_CTX[0], *self.START_CTX['argv'])
+        self.cfg.pre_exec(self)
+        os.execvpe(self.START_CTX[0], self.START_CTX['args'], os.environ)
 
     def murder_workers(self):
         """\
@@ -363,7 +362,7 @@ class Arbiter(object):
             self.worker_age += 1
             worker = self.worker_class(self.worker_age, self.pid, self.LISTENER,
                                         self.app, self.timeout/2.0, self.cfg)
-            self.cfg.before_fork(self, worker)
+            self.cfg.pre_fork(self, worker)
             pid = os.fork()
             if pid != 0:
                 self.WORKERS[pid] = worker
@@ -375,7 +374,7 @@ class Arbiter(object):
                 util._setproctitle("worker [%s]" % self.proc_name)
                 self.log.debug("Booting worker: %s (age: %s)" % (
                                                 worker_pid, self.worker_age))
-                self.cfg.after_fork(self, worker)
+                self.cfg.post_fork(self, worker)
                 worker.init_process()
                 sys.exit(0)
             except SystemExit:
