@@ -89,12 +89,12 @@ class SyncWorker(Worker):
             util.close(client)
 
     def handle_request(self, client, addr):
-        req = http.Request(client, addr, self.address, self.cfg)
+        req = http.Request(self.cfg, client, addr, self.address)
         try:
             environ = req.read()
             if not environ or not req.parser.status_line:
                 return
-            respiter = self.app(environ, req.start_response)
+            respiter = self.wsgi(environ, req.start_response)
             for item in respiter:
                 req.response.write(item)
             req.response.close()
